terrarium — Terrarium 1.0.1 documentation

# terrarium

- Installation
  - Requirements
  - Install using pip
  - Upgrade using pip
- Quick Start
  - Creating a new environment
  - Replacing an existing environment
- User Guide
  - Creating a new environment
  - Replacing an existing environment
  - Saving and using environment archives
  - Tips
- Development
  - Installing requirements
  - Building the documentation locally
  - Running tests
  - Getting involved
  - Release process
- Release Notes